@@ -14,8 +14,8 @@
 #  limitations under the License.
 
 import blockdiag.drawer
+
 from actdiag.metrics import DiagramMetrics
-from blockdiag.utils.compat import u, string_types
 
 
 class DiagramDraw(blockdiag.drawer.DiagramDraw):
@@ -29,10 +29,10 @@ class DiagramDraw(blockdiag.drawer.DiagramDraw):
         for i, lane in enumerate(self.diagram.lanes):
             if lane.label:
                 label = lane.label
-            elif isinstance(lane.id, string_types):
+            elif isinstance(lane.id, str):
                 label = lane.id
             else:
-                label = u('Lane %d') % (i + 1)
+                label = 'Lane %d' % (i + 1)
 
             if lane.href and self.format == 'SVG':
                 drawer = self.drawer.anchor(lane.href)
