@@ -13,13 +13,10 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from docutils.parsers import rst
-import actdiag.parser
-import actdiag.builder
-import actdiag.drawer
-from actdiag.utils.rst.nodes import actdiag as actdiag_node
 from blockdiag.utils.rst import directives
+from docutils.parsers import rst
 
+from actdiag.utils.rst.nodes import actdiag as actdiag_node
 
 directive_options_default = dict(format='PNG',
                                  antialias=False,
@@ -34,7 +31,6 @@ directive_options = {}
 class ActdiagDirective(directives.BlockdiagDirective):
     name = "actdiag"
     node_class = actdiag_node
-    processor = actdiag
 
     @property
     def global_options(self):
